edist.NumberedPoint

Module edist :: Class NumberedPoint |
[hide private]
[frames] | no frames]

# Class NumberedPoint

             object --+
                      |
    upoints.point.Point --+
                          |
                         NumberedPoint

Class for representing locations from command line

Since: 0.6.0

Instance Methods | [hide private]
__init__(self, latitude, longitude, name, units=`'``km``'`) Initialise a new NumberedPoint object |
Inherited from `upoints.point.Point`: `__dict__`, `__eq__`, `__hash__`, `__ne__`, `__repr__`, `__str__`, `__unicode__`, `bearing`, `destination`, `distance`, `final_bearing`, `forward`, `inverse`, `midpoint`, `sun_events`, `sunrise`, `sunset`, `to_grid_locator` Inherited from `upoints.point.Point` (private): `_set_location` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Instance Variables | [hide private]
| name A name for location, or its position on the command line
| units Type of distance units to be used
Inherited from `upoints.point.Point`: `latitude`, `longitude`, `rad_latitude`, `rad_longitude`, `timezone`

Properties | [hide private]
Inherited from `upoints.point.Point` (private): `_angle`, `_latitude`, `_longitude`, `_rad_latitude`, `_rad_longitude` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, latitude, longitude, name, units=`'``km``'`) (Constructor) |
Initialise a new NumberedPoint object
    >>> NumberedPoint(52.015, -0.221, 4)
    NumberedPoint(52.015, -0.221, 4, 'metric')
    >>> NumberedPoint(52.015, -0.221, "Home")
    NumberedPoint(52.015, -0.221, 'Home', 'metric')
Parameters: `latitude` (`float` or coercible to `float`) - Location's latitude `longitude` (`float` or coercible to `float`) - Location's longitude `name` (`str`) - Location's name or command line position `units` (`str`) - Unit type to be used for distances Raises: `ValueError` - Unknown value for `angle` `ValueError` - Unknown value for units `ValueError` - Invalid value for latitude or longitude Overrides: object.__init__